@@ -150,7 +150,7 @@ class PortfolioDataApi(metaclass=Singleton):
             if start_date is None:
                 _start_date = ''
             else:
-                _start_date = start_date-datetime.timedelta(days=20)
+                _start_date = start_date-datetime.timedelta(days=40)
             end_date = end_date if end_date is not None else ''
             mutual_fund_nav = pd.DataFrame()
             hedge_fund_nav = pd.DataFrame
@@ -181,6 +181,46 @@ class PortfolioDataApi(metaclass=Singleton):
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from portfolio.get_all_fund_nav')
 
+    def get_all_fund_nav_(self, start_date=None, end_date=None, fund_list: Tuple[str] = ()):
+        try:
+            if start_date is None:
+                _start_date = ''
+            else:
+                _start_date = start_date-datetime.timedelta(days=40)
+            end_date = end_date if end_date is not None else ''
+            mutual_fund_nav = pd.DataFrame()
+            hedge_fund_nav = pd.DataFrame
+            #print(f'start_date {start_date} end_date {end_date} fund_list {fund_list}')
+            if len(fund_list) > 0:
+                mutual_fund_list = [_ for _ in fund_list if '!' in _]
+                hedge_fund_list = [_ for _ in fund_list if '!' not in _]
+                if len(mutual_fund_list) > 0:
+                    mutual_fund_nav = BasicDataApi().get_fund_nav_with_date(start_date=_start_date,end_date=end_date,fund_list=mutual_fund_list)
+                if len(hedge_fund_list) > 0:
+                    hedge_fund_nav = RawDataApi().get_hf_fund_nav(fund_ids=hedge_fund_list, start_date=_start_date, end_date=end_date)
+            else:
+                mutual_fund_nav = BasicDataApi().get_fund_nav_with_date(start_date=_start_date,end_date=end_date)
+                hedge_fund_nav = RawDataApi().get_hf_fund_nav_dt(start_date=_start_date, end_date=end_date)
+
+            if not mutual_fund_nav.empty:
+                mutual_fund_nav = mutual_fund_nav.pivot_table(index='datetime',columns='fund_id',values='adjusted_net_value')
+            if not hedge_fund_nav.empty:
+                hedge_fund_nav = hedge_fund_nav.pivot_table(index='datetime',columns='fund_id',values='nav')
+            df_list = [i for i in [mutual_fund_nav, hedge_fund_nav] if not i.empty ]
+            if isinstance(start_date, str):
+                fund_nav = pd.concat(df_list, axis=1)
+                fund_nav = fund_nav.reindex(fund_nav.index.union([start_date])).sort_index().ffill()
+            else:
+                fund_nav = pd.concat(df_list, axis=1)
+                fund_nav = fund_nav.reindex(fund_nav.index.union([start_date])).sort_index().ffill().loc[start_date:]
+            fund_nav.index.name = 'datetime'
+            return fund_nav
+
+        except Exception as e:
+            print(f'Failed to get data <err_msg> {e} from portfolio.get_all_fund_nav')
+
+
+
     def trade_history_parse(self, trade_history):
         try:
             fund_type = {}
@@ -338,7 +378,7 @@ class PortfolioDataApi(metaclass=Singleton):
             index_price = basic.get_index_and_asset_price(index_list=[index_id],begin_date=fund_nav.index[0], end_date=fund_nav.index[-1])
             name_dic = basic.get_index_and_asset_name_dic([index_id])
             begin_date, end_date = RawDataApi().get_date_range(time_para, begin_date, end_date)
-            df = pd.merge(fund_nav.reset_index(), index_price.reset_index(),how='outer').set_index('datetime').sort_index().ffill().dropna().reindex(fund_nav.index)
+            df = pd.merge(fund_nav.reset_index(), index_price.reset_index(),how='outer').set_index('datetime').sort_index().ffill().dropna().reindex(fund_nav.index).bfill()
             df = df.loc[begin_date:end_date]
             df = df / df.iloc[0]
             df.loc[:,'价格比'] = df.组合 / df[index_id]
@@ -703,14 +743,12 @@ class PortfolioDataApi(metaclass=Singleton):
                     next_date = list(share_list.keys())[i+1]
                 else :
                     next_date = datetime.date.today()
-
                 if next_date <= begin_date: 
                     continue
                 elif next_date <= end_date: 
                     cal_end = next_date
                 elif next_date > end_date: 
                     cal_end = end_date
-
                 if this_date >= end_date: 
                     break
                 elif this_date <= begin_date: 
@@ -720,7 +758,7 @@ class PortfolioDataApi(metaclass=Singleton):
                 ret_dict = {}
                 for fund_id in list(share_list[this_date].keys()):
                     fund_share = share_list[this_date][fund_id]
-                    fund_nav = self.get_all_fund_nav(start_date=cal_start,end_date=cal_end,fund_list=[fund_id])
+                    fund_nav = self.get_all_fund_nav_(start_date=cal_start,end_date=cal_end,fund_list=[fund_id])
                     fund_nav = fund_nav.ffill()
                     fund_ret = round((fund_nav.iloc[-1].values[0] * fund_share - fund_nav.iloc[0].values[0] * fund_share)*100,2)
                     ret_dict[desc_name_dic[fund_id]] = fund_ret
@@ -825,8 +863,8 @@ class PortfolioDataApi(metaclass=Singleton):
             for date_group in date_list:
                 b_d = date_group[0]
                 e_d = date_group[1]
-                fund_wgt_dt = fund_wgt.loc[b_d].dropna()
-                mdd_i = ((fund_nav.loc[e_d] / fund_nav.loc[b_d] - 1) * fund_wgt_dt)
+                fund_wgt_dt = fund_wgt.loc[:b_d].iloc[-1].dropna()
+                mdd_i = ((fund_nav.loc[:e_d].iloc[-1] / fund_nav.loc[:b_d].iloc[-1] - 1) * fund_wgt_dt)
                 _mdd_list.append(mdd_i.dropna())
             mdd_dict = ((pd.concat(_mdd_list,axis=1).fillna(0) + 1).prod(axis=1) - 1).to_dict()
             df_result = pd.DataFrame([desc_name_dic]).T
@@ -890,10 +928,10 @@ class PortfolioDataApi(metaclass=Singleton):
                 for dts in dts_list:
                     b_d = dts[0]
                     e_d = dts[1]
-                    fund_wgt_i = fund_wgt.loc[b_d:e_d].iloc[:-1].dropna(axis=1)
-                    type_fund_list = fund_wgt_i.columns.intersection(_fund_list) 
-                    wgts = fund_wgt_i[type_fund_list].mean()
-                    _fund_nav = fund_nav.loc[b_d:e_d].iloc[:-1][type_fund_list]
+                    fund_wgt_i = fund_wgt.loc[b_d:].iloc[0]
+                    type_fund_list = fund_wgt_i.index.intersection(_fund_list).tolist() 
+                    wgts = fund_wgt_i[type_fund_list]
+                    _fund_nav = fund_nav.loc[b_d:e_d][type_fund_list]
                     _fund_ret = (_fund_nav.iloc[-1] / _fund_nav.iloc[0] - 1)# * wgts
                     _fund_ret = _fund_ret.to_dict()
                     index_id = benchmark_id_info[fund_ti]
@@ -966,7 +1004,7 @@ class PortfolioDataApi(metaclass=Singleton):
             benchmark_id_info_r = {v: k for k, v in benchmark_id_info.items()}
             index_price = BasicDataApi().get_index_and_asset_price(index_list=list(benchmark_id_info.values()),begin_date=fund_nav.index[0], end_date=fund_nav.index[-1])
             index_price = index_price.rename(columns=benchmark_id_info_r)
-            index_price = index_price.reindex(_index_price.index)
+            index_price = index_price.reindex(_index_price.index.union(index_price.index)).ffill().bfill().reindex(_index_price.index)
             result_2 = _index_price / _index_price.iloc[0] / (index_price / index_price.iloc[0])
 
             price_ratio = result_2.copy()
@@ -974,9 +1012,12 @@ class PortfolioDataApi(metaclass=Singleton):
             result_2_str = ' '.join([f'{k} {int(v)}BP' for k, v in res_2_dic.items()])
 
             fund_navs = result['各基净值']
+            _port_index_list = result['净值'].index.tolist()
             _result_3 = []
             for dts in date_pairs:
                 b_d, e_d = dts
+                if e_d <= _port_index_list[0] or b_d >= _port_index_list[-1]:
+                    continue
                 if dts != date_pairs[-1]:
                     _fund_wgt = fund_wgt.loc[b_d:e_d].iloc[:-1]
                 else:
