@@ -15,6 +15,7 @@ from ...view.derived_models import *
 from .derived_data_helper import DerivedDataHelper
 from ...api.derived import DerivedDataApi
 
+
 class FundIndicatorProcessor(object):
 
     TRADING_DAYS_PER_YEAR = 242
@@ -351,3 +352,8 @@ class FundIndicatorProcessor(object):
             failed_tasks.append('fund_indicator')
 
         return failed_tasks
+
+
+if __name__ == '__main__':
+    fip = FundIndicatorProcessor(DerivedDataHelper())
+    fip.process('20210201', '20210201')
