@@ -25,17 +25,19 @@ class HedgeFundDataManager(metaclass=Singleton):
     def __init__(self):
         pass
 
-    def _get_total_share(self, manager_id: str, fof_id: str, investor_id: str = '', exclude1: List[int] = [], exclude2: List[str] = []) -> Tuple[float, pd.DataFrame]:
+    def _get_total_share(self, manager_id: str, fof_id: str, date: datetime.date, investor_id: str = '', exclude1: List[int] = [], exclude2: List[str] = []) -> Tuple[float, pd.DataFrame]:
         part1 = DerivedDataApi().get_hedge_fund_investor_pur_redemp(manager_id, [fof_id])
         assert part1 is not None, '!!!!'
+        part1 = part1[part1.datetime <= date]
         part1 = part1[~part1.id.isin(exclude1)]
         part1_total_share = part1.share_changed.sum()
         if investor_id:
             part1 = part1.loc[part1.investor_id == investor_id, :]
 
         part2 = DerivedDataApi().get_hedge_fund_investor_div_carry(manager_id, [fof_id])
-        part2 = part2[~part2.id.isin(exclude2)]
         assert part2 is not None, '!!!!'
+        part2 = part2[part2.datetime <= date]
+        part2 = part2[~part2.id.isin(exclude2)]
         part2_total_share = part2.share_changed.sum()
         if investor_id:
             part2 = part2.loc[part2.investor_id == investor_id, :]
@@ -175,7 +177,7 @@ class HedgeFundDataManager(metaclass=Singleton):
         else:
             raise ValueError(f'invalid event_type {event_type}')
 
-        _, share_separate = self._get_total_share(datas['manager_id'], datas['fof_id'], datas['investor_id'], exclude1=[datas['id']] if 'id' in datas else [])
+        _, share_separate = self._get_total_share(datas['manager_id'], datas['fof_id'], datas['datetime'], datas['investor_id'], exclude1=[datas['id']] if 'id' in datas else [])
         try:
             datas['share_after_trans'] = float(share_separate.at[datas['investor_id'], 'share_changed']) + datas['share_changed']
         except KeyError:
@@ -207,14 +209,13 @@ class HedgeFundDataManager(metaclass=Singleton):
             return profit * float(fee_desc)
         elif fee_type == '2':
             fee_df = pd.DataFrame(json.loads(fee_desc)).sort_values(by='start', ascending=False)
-            if fee_df.empty:
-                assert False, f'invalid fee str {fee_desc} (fee_type){fee_type}'
+            assert not fee_df.empty, f'invalid fee str {fee_desc} (fee_type){fee_type}'
             total_profit = 0
             for row in fee_df.itertuples(index=False):
                 assert profit > 0, '!!!!'
-                level_profit: float = row.start * water_line
+                level_profit: float = water_line * (row.start if row.start else 0)
                 if profit > level_profit:
-                    total_profit += (profit - level_profit) * row.val
+                    total_profit += (profit - level_profit) * (row.val if row.val else 0)
                     profit = level_profit
             return total_profit
         else:
@@ -274,7 +275,7 @@ class HedgeFundDataManager(metaclass=Singleton):
             # 计提业绩报酬 暂不需要额外处理
             pass
         else:
-            total_share, share_separate = self._get_total_share(datas['manager_id'], datas['fof_id'], datas['investor_id'])
+            total_share, share_separate = self._get_total_share(datas['manager_id'], datas['fof_id'], datas['datetime'], datas['investor_id'])
             share_separate = share_separate.share_changed.array[-1]
             # div = datas['total_dividend'] * share_separate / total_share
 
@@ -347,7 +348,7 @@ class HedgeFundDataManager(metaclass=Singleton):
         throw excepion if failed, or return a pd.DataFrame if succeed
         '''
 
-        total_share, share_separate = self._get_total_share(datas['manager_id'], datas['fof_id'])
+        total_share, share_separate = self._get_total_share(datas['manager_id'], datas['fof_id'], datas['datetime'])
         share_separate = share_separate.share_changed
         weight = share_separate / total_share
 
