@@ -120,15 +120,16 @@ class ResearchNAVReader:
                     df.to_sql(FOFNavPublic.__table__.name, DerivedDatabaseConnector().get_engine(), index=False, if_exists='append')
                     update_info[fund_id] = df.shape[0]
 
-                fof_nav_public = DerivedDataApi().get_fof_nav_public(fof_id_list=[fund_id])
-                if fof_nav_public is not None and not fof_nav_public.empty:
-                    fof_nav_public = fof_nav_public.set_index('datetime')['adjusted_nav']
+                fof_nav = DerivedDataApi().get_fof_nav_public(fof_id_list=[fund_id])
+                if fof_nav is not None and not fof_nav.empty:
+                    fof_nav_public = fof_nav.set_index('datetime')['adjusted_nav']
                     res_status = Calculator.get_stat_result(fof_nav_public.index, fof_nav_public.array)
                     Session = sessionmaker(BasicDatabaseConnector().get_engine())
                     db_session = Session()
                     # '1' 表示公有的 FOFInfo
                     fof_info_to_set = db_session.query(FOFInfo).filter(FOFInfo.manager_id == '1', FOFInfo.fof_id == fund_id).one_or_none()
-                    fof_info_to_set.net_asset_value = float(res_status.last_unit_nav) if not pd.isnull(res_status.last_unit_nav) else None
+                    fof_info_to_set.net_asset_value = float(fof_nav.nav.array[-1]) if not pd.isnull(fof_nav.nav.array[-1]) else None
+                    fof_info_to_set.acc_unit_value = float(fof_nav.acc_net_value.array[-1]) if not pd.isnull(fof_nav.acc_net_value.array[-1]) else None
                     fof_info_to_set.adjusted_net_value = float(fof_nav_public.array[-1]) if not pd.isnull(fof_nav_public.array[-1]) else None
                     fof_info_to_set.latest_cal_date = res_status.end_date
                     fof_info_to_set.ret_year_to_now = float(res_status.recent_year_ret) if not pd.isnull(res_status.recent_year_ret) else None
