@@ -888,31 +888,42 @@ class FOFInfo(FOFBase):
 
     __tablename__ = 'fof_info'
 
-    fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
-    manager_id = Column(VARCHAR(32), primary_key=True)  # 管理端ID
-    datetime = Column(CHAR(16))  # 数据日期（以支持更新操作）
-    fof_name = Column(TEXT, nullable=False)  # 产品名称
-    desc_name = Column(CHAR(31))  # 简称
-    admin = Column(TEXT)  # 管理人
-    established_date = Column(DATE, nullable=False)  # 成立日期
-    fof_status = Column(CHAR(16))  # 申赎状态等
-    subscription_fee = Column(DOUBLE(asdecimal=False))  # 认购费率
-    redemption_fee = Column(TEXT)  # 赎回费率
-    management_fee = Column(DOUBLE(asdecimal=False))  # 管理费率
-    custodian_fee = Column(DOUBLE(asdecimal=False))  # 托管费率
-    administrative_fee = Column(DOUBLE(asdecimal=False))  # 行政管理费率
-    lock_up_period = Column(TEXT)  # 锁定期
-    incentive_fee_mode = Column(VARCHAR(31))  # 业绩报酬计提方法
-    incentive_fee_type = Column(VARCHAR(31))  # 业绩报酬计提类型
-    incentive_fee_str = Column(VARCHAR(255))  # 业绩报酬提取规则
+    fof_id = Column(CHAR(16), primary_key=True)             # 产品ID
+    manager_id = Column(VARCHAR(32), primary_key=True)      # 管理端ID
+    datetime = Column(CHAR(16))                             # 数据日期（以支持更新操作）
+    fof_name = Column(TEXT, nullable=False)                 # 产品名称
+    desc_name = Column(CHAR(31))                            # 简称
+    admin = Column(TEXT)                                    # 管理人
+    established_date = Column(DATE, nullable=False)         # 成立日期
+    running_start_date = Column(DATE, nullable=False)       # 实际运作起始日期
+    fof_status = Column(CHAR(16))                           # 申赎状态等
+    subscription_fee = Column(TEXT)                         # 认购费率
+    purchase_fee = Column(TEXT)                             # 申购费率
+    redemption_fee = Column(TEXT)                           # 赎回费率
+    sale_proxy_fee = Column(TEXT)                           # 代销费率
+    management_fee = Column(DOUBLE(asdecimal=False))        # 管理费率
+    custodian_fee = Column(DOUBLE(asdecimal=False))         # 托管费率
+    min_custodian_fee_amt = Column(DOUBLE(asdecimal=False)) # 托管费率最小金额
+    administrative_fee = Column(DOUBLE(asdecimal=False))    # 行政管理费率
+    min_admin_fee_amt = Column(DOUBLE(asdecimal=False))     # 行政管理费率最小金额
+    lock_up_period = Column(TEXT)                           # 锁定期
+    stop_loss = Column(TEXT)                                # 预警/止损配置
+    incentive_fee_mode = Column(VARCHAR(31))                # 业绩报酬计提方法
+    incentive_fee_type = Column(VARCHAR(31))                # 业绩报酬计提类型
+    incentive_fee_str = Column(VARCHAR(255))                # 业绩报酬提取规则
+    incentive_fee_time = Column(TEXT)                       # 业绩报酬提取时点
     current_deposit_rate = Column(DOUBLE(asdecimal=False))  # 银行活期存款利率
-    initial_raised_fv = Column(DOUBLE(asdecimal=False))  # 初始募集面值
-    initial_net_value = Column(DOUBLE(asdecimal=False))  # 期初总资产净值
-    total_volume = Column(DOUBLE(asdecimal=False))      # 总资产份额
-    total_amount = Column(DOUBLE(asdecimal=False))      # 资产总额
-    net_asset_value = Column(DOUBLE(asdecimal=False))  # 单位净值
-    acc_unit_value = Column(DOUBLE(asdecimal=False))  # 累计净值
-    adjusted_net_value = Column(DOUBLE(asdecimal=False))  # 复权净值
+    purchase_redeem_appointment = Column(TEXT)              # 预约申赎机制
+    force_redemption = Column(TEXT)                         # 违约赎回机制
+    huge_redemption_thres = Column(DOUBLE(asdecimal=False)) # 巨额赎回认定比例
+    dividend_distribution = Column(TEXT)                    # 分红分配方式
+    initial_raised_fv = Column(DOUBLE(asdecimal=False))     # 初始募集面值
+    initial_net_value = Column(DOUBLE(asdecimal=False))     # 期初总资产净值
+    total_volume = Column(DOUBLE(asdecimal=False))          # 总资产份额
+    total_amount = Column(DOUBLE(asdecimal=False))          # 资产总额
+    net_asset_value = Column(DOUBLE(asdecimal=False))       # 单位净值
+    acc_unit_value = Column(DOUBLE(asdecimal=False))        # 累计净值
+    adjusted_net_value = Column(DOUBLE(asdecimal=False))    # 复权净值
     ret_year_to_now = Column(DOUBLE(asdecimal=False))       # 今年以来收益率
     ret_total = Column(DOUBLE(asdecimal=False))             # 总收益率
     ret_ann = Column(DOUBLE(asdecimal=False))               # 总收益率年化
@@ -943,6 +954,7 @@ class FOFInfo(FOFBase):
     fof_manager = Column(VARCHAR(16))                       # 基金经理
     benchmark_index = Column(VARCHAR(127))                  # 基准指数
     open_date = Column(CHAR(63))                            # 开放日
+    temp_open_times = Column(TEXT)                          # 临时开放次数
     stars = Column(Integer, server_default=text('1'))       # 星级
     is_structured = Column(BOOLEAN, default=False)          # 是否是分级基金
     main_fof_id = Column(VARCHAR(32))                       # 主ID
