@@ -147,8 +147,12 @@ class CalculatorBase:
         for _period, _period_begin_date in begin_date_dic.items():
             if _period_begin_date >= _begin_date and sr.index[-1] > _period_begin_date:
                 _res[_period] = sr.loc[:last_date][-1] / sr.loc[_period_begin_date:][0] - 1
+                if _period == 'w1':
+                    _res['w1_begin_date'] = sr.loc[_period_begin_date:].index[0]
+                    _res['w1_end_date'] = sr.loc[:last_date].index[-1]
             else:
                 _res[_period] = np.nan
+                
         recent_1w_ret = _res['w1']
         recent_1m_ret = _res['m1']
         recent_3m_ret = _res['m3']
@@ -158,6 +162,13 @@ class CalculatorBase:
         recent_3y_ret = _res['y3']
         recent_4y_ret = _res['y4']
         recent_5y_ret = _res['y5']
+        if 'w1_begin_date' in _res:
+            w1_begin_date = _res['w1_begin_date']
+            w1_end_date = _res['w1_end_date']
+        else:
+            w1_begin_date = sr.index[0]
+            w1_end_date = sr.index[-1]
+
         history_ret = sr.loc[:last_date][-1] / sr[0] - 1
         days = (dates[-1] - dates[0]).days
         history_annual_ret = math.pow(history_ret + 1, CalculatorBase.TOTAL_DAYS_PER_YEAR/days) - 1 if days != 0 else 0
@@ -196,6 +207,8 @@ class CalculatorBase:
             'history_annual_ret':history_annual_ret,
             'y_2020_ret':y_2020_ret,
             'last_year_ret':y_last_ret,
+            'w1_begin_date':w1_begin_date,
+            'w1_end_date':w1_end_date,
         }
 
     @staticmethod
@@ -371,9 +384,14 @@ class CalculatorBase:
         last_date, begin_date_dic = CalculatorBase.get_begin_date_dic(week_end_date = _end_dt)
         assert len(dates) == len(values), 'date and port_values has different numbers'
         if len(dates) > 2:
-            sr = pd.Series(values, index=dates).sort_index().dropna()
+            sr = pd.Series(values, index=dates).sort_index()
             sr = sr.set_axis(pd.to_datetime(sr.index), inplace=False).resample(frequency).last().dropna()
             sr.index = [i.date() for i in sr.index]
+            natural_day_lenth = (sr.index[-1] - sr.index[0]).days
+            price_num = sr.dropna().shape[0]
+            nav_density = price_num / natural_day_lenth
+            nav_type = CalculatorBase.get_nav_type(values=values, dates=dates)
+            sr = sr.dropna()
             if frequency == '1D':            
                 period_1m = 20
                 period_3m = period_1m * 3
@@ -422,6 +440,8 @@ class CalculatorBase:
             recent_5y_ret = recent_ret_res['recent_5y_ret']
             recent_4w_ret = recent_ret_res['recent_4w_ret']
             last_year_ret = recent_ret_res['last_year_ret']
+            w1_begin_date = recent_ret_res['w1_begin_date']
+            w1_end_date = recent_ret_res['w1_end_date']
             y_2020_ret = recent_ret_res['y_2020_ret']
             worst_3m_ret = sr.pct_change(period_3m).min()
             worst_6m_ret = sr.pct_change(period_6m).min()
@@ -632,6 +652,10 @@ class CalculatorBase:
                     'mdd_recover_date2':mdd_recover_date2,
                     'mdd_recover_lens':mdd_recover_lens,
                     'win_rate_0_period':win_rate_0_period,
+                    'nav_density':nav_density,
+                    'nav_type':nav_type,
+                    'w1_begin_date':w1_begin_date,
+                    'w1_end_date':w1_end_date,
                 }
             else:
                 return {
@@ -680,6 +704,10 @@ class CalculatorBase:
                     'mdd_recover_date2':mdd_recover_date2,
                     'mdd_recover_lens':mdd_recover_lens,
                     'win_rate_0_period':win_rate_0_period,
+                    'nav_density':nav_density,
+                    'nav_type':nav_type,
+                    'w1_begin_date':w1_begin_date,
+                    'w1_end_date':w1_end_date,
                 }
         else:
             return {
@@ -760,6 +788,10 @@ class CalculatorBase:
                     'mdd_recover_date2':dates[0] if len(dates) > 0 else None,
                     'mdd_recover_lens':0,
                     'win_rate_0_period':0,
+                    'nav_density':0,
+                    'nav_type':'nan',
+                    'w1_begin_date':dates[0] if len(dates) > 0 else None,
+                    'w1_end_date':dates[0] if len(dates) > 0 else None,
                 }
 
 
@@ -977,3 +1009,36 @@ class CalculatorBase:
         df.index = [i.date() for i in df.index]
         df.index.name = 'datetime'
         return df
+
+    @staticmethod
+    def get_nav_type(values, dates):
+        sr = pd.Series(values, index=dates).sort_index()
+        tds = pd.to_datetime(sr.index)
+        tds = [_.date() for _ in tds]
+        sr.index = tds
+        dts = BasicDataApi().get_trading_day_list(start_date=sr.index[0], end_date=sr.index[-1]).set_index('datetime')
+        sr_daily = sr.reindex(dts.index)
+        sr_week = CalculatorBase.data_resample_weekly_nav(df=sr_daily)
+        sr_month = CalculatorBase.data_resample_monthly_nav(df=sr_daily)
+
+        nav_density_daily = 1 - (sum(sr_daily.isnull() * 1) / sr_daily.shape[0])
+        nav_density_weeky = 1 - (sum(sr_week.isnull() * 1) / sr_week.shape[0])
+        nav_density_monthy = 1 - (sum(sr_month.isnull() * 1) / sr_month.shape[0])
+
+        # 如果周度净值价格都在非交易日上，比如周日
+        if sr.dropna().shape[0] > 0 and nav_density_monthy == 0:
+            sr = pd.Series(values, index=dates).sort_index()
+            sr_week = CalculatorBase.data_resample_weekly_nav(df=sr)
+            sr_week = sr.reindex(dts.index)
+            sr_week = CalculatorBase.data_resample_weekly_nav(df=sr)
+            sr_month = CalculatorBase.data_resample_monthly_nav(df=sr_week)
+            nav_density_weeky = 1 - (sum(sr_week.isnull() * 1) / sr_week.shape[0])
+            nav_density_monthy = 1 - (sum(sr_month.isnull() * 1) / sr_month.shape[0])
+            
+        if nav_density_daily > 0.8:
+            fund_nav_type = 'daily'
+        elif nav_density_weeky > 0.8:
+            fund_nav_type = 'weekly'
+        else:
+            fund_nav_type = 'monthly'
+        return fund_nav_type
\ No newline at end of file
