@@ -123,11 +123,15 @@ class SurfingConfigurator(metaclass=Singleton):
         return settings[key]
 
     def get_wechat_webhook_settings(self, key=None):
+        key_map = {
+            'wechat_webhook': 'SURFING_WECHAT_WEBHOOK',
+            'wechat_webhook_err_msg': 'SURFING_WECHAT_ERR_MSG_WEBHOOK',
+        }
         try:
-            settings = os.environ['SURFING_WECHAT_WEBHOOK']
+            settings = os.environ[key_map[key]]
         except KeyError:
-            assert 'wechat_webhook' in self.config, 'could not find wechat_webhook section in env and config'
-            settings = self.config['wechat_webhook']
+            # assert key in self.config, f'could not find {key} section in env and config'
+            settings = self.config[key] if key in self.config else None
         return settings
 
     def get_cassandra_setting(self):
