@@ -17,8 +17,15 @@ class WechatBot(object):
 
     def __init__(self):
         self.wechat_webhook = SurfingConfigurator().get_wechat_webhook_settings('wechat_webhook')
+        assert self.wechat_webhook is not None, 'could not find wechat_webhook config'
+        self._wechat_err_msg_webhook = SurfingConfigurator().get_wechat_webhook_settings('wechat_webhook_err_msg')
+        if self._wechat_err_msg_webhook is None:
+            self._wechat_err_msg_webhook = self.wechat_webhook
+
+    def send(self, markdown_content, webhook=None):
+        if webhook is None and self.wechat_webhook is None:
+            return
 
-    def send(self, markdown_content):
         print(markdown_content)
         i = 0
         while i < len(markdown_content):
@@ -50,7 +57,7 @@ class WechatBot(object):
                 }
             }
             try:
-                res = requests.post(url=self.wechat_webhook, data=json.dumps(message), timeout=20)
+                res = requests.post(url=self.wechat_webhook if webhook is None else webhook, data=json.dumps(message), timeout=20)
                 print(res)
                 time.sleep(4)
             except Exception as e:
@@ -133,7 +140,7 @@ class WechatBot(object):
     def send_hedge_fund_nav_update_failed(self, err_msg: str):
         markdown_content = '#### <font color=\"warning\">产品净值数据更新错误！！</font>'
         markdown_content += f'\n>**err msg:** {err_msg}'
-        self.send(markdown_content)
+        self.send(markdown_content, webhook=self._wechat_err_msg_webhook)
 
     def send_hedge_fund_info(self, fof_id: str, fund_id: str, fund_name: str, latest_nav_date: datetime.date, fund_data, holding_data, ret_data_with_last_date, ret_date_with_last_pub):
         _FUND_DATA_NAME_DICT = {
